@@ -120,17 +120,17 @@ defmodule Ejabberd.MixProject do
      {:dialyxir, "~> 1.2", only: [:test], runtime: false},
      {:eimp, "~> 1.0"},
      {:ex_doc, "~> 0.31", only: [:edoc], runtime: false},
-     {:fast_tls, "~> 1.1.22"},
-     {:fast_xml, "~> 1.1.53"},
+     {:fast_tls, "~> 1.1.24"},
+     {:fast_xml, "~> 1.1.56"},
      {:fast_yaml, "~> 1.0"},
      {:idna, "~> 6.0"},
      {:mqtree, "~> 1.0"},
-     {:p1_acme, "~> 1.0"},
+     {:p1_acme, "~> 1.0.27"},
      {:p1_oauth2, "~> 0.6"},
      {:p1_utils, "~> 1.0"},
      {:pkix, "~> 1.0"},
      {:stringprep, ">= 1.0.26"},
-     {:xmpp, "~> 1.10.0"},
+     {:xmpp, ">= 1.11.0"},
      {:yconf, ">= 1.0.18"}]
     ++ cond_deps()
   end
