@@ -44,6 +44,7 @@ start(normal, _Args) ->
 	ejabberd_logger:start(),
 	write_pid_file(),
 	start_included_apps(),
+	misc:warn_unset_home(),
 	start_elixir_application(),
 	setup_if_elixir_conf_used(),
 	case ejabberd_config:load() of
@@ -108,6 +109,7 @@ prep_stop(State) ->
     ejabberd_service:stop(),
     ejabberd_s2s:stop(),
     ejabberd_system_monitor:stop(),
+    gen_mod:prep_stop(),
     gen_mod:stop(),
     State.
 
@@ -176,6 +178,10 @@ file_queue_init() ->
 	Err -> throw({?MODULE, Err})
     end.
 
+%%%
+%%% Elixir
+%%%
+
 -ifdef(ELIXIR_ENABLED).
 is_using_elixir_config() ->
     Config = ejabberd_config:path(),
