@@ -5,7 +5,7 @@
 %%% Created : 11 Jan 2004 by Alexey Shchepin <alexey@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2024   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2025   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -28,7 +28,7 @@
 -behaviour(gen_server).
 -author('alexey@process-one.net').
 
--export([start/0, start_link/0, process/1, process2/2]).
+-export([start/0, start_link/0, process/1, process/2, process2/2]).
 %% gen_server callbacks
 -export([init/1, handle_call/3, handle_cast/2, handle_info/2,
 	 terminate/2, code_change/3]).
@@ -37,6 +37,7 @@
 
 -include("ejabberd_ctl.hrl").
 -include("ejabberd_commands.hrl").
+-include("ejabberd_http.hrl").
 -include("logger.hrl").
 -include("ejabberd_stacktrace.hrl").
 
@@ -115,15 +116,44 @@ code_change(_OldVsn, State, _Extra) ->
     {ok, State}.
 
 %%-----------------------------
-%% Process
+%% Process http
+%%-----------------------------
+
+-spec process_http([binary()], tuple()) -> {non_neg_integer(), [{binary(), binary()}], string()}.
+
+process_http([_Call], #request{data = Data, path = [<<"ctl">> | _]}) ->
+    Args = [binary_to_list(E) || E <- misc:json_decode(Data)],
+    process_http2(Args, ?DEFAULT_VERSION).
+
+process_http2(["--version", Arg | Args], _) ->
+    Version =
+	try
+	    list_to_integer(Arg)
+	catch _:_ ->
+		throw({invalid_version, Arg})
+	end,
+    process_http2(Args, Version);
+
+process_http2(Args, Version) ->
+    {String, Code} = process2(Args, [], Version),
+    String2 = case String of
+                  [] -> String;
+                  _ -> [String, "\n"]
+              end,
+    {200, [{<<"status-code">>, integer_to_binary(Code)}], String2}.
+
+%%-----------------------------
+%% Process command line
 %%-----------------------------
 
 -spec process([string()]) -> non_neg_integer().
 process(Args) ->
     process(Args, ?DEFAULT_VERSION).
 
+-spec process([string() | binary()], non_neg_integer() | tuple()) -> non_neg_integer().
 
--spec process([string()], non_neg_integer()) -> non_neg_integer().
+process([Call], Request) when is_binary(Call) and is_record(Request, request) ->
+    process_http([Call], Request);
 
 %% The commands status, stop and restart are defined here to ensure
 %% they are usable even if ejabberd is completely stopped.
@@ -232,7 +262,7 @@ process2(Args, AccessCommands, Auth, Version) ->
 	    io:format(lists:flatten(["\n" | String]++["\n"])),
 	    [CommandString | _] = Args,
             process(["help" | [CommandString]], Version),
-	    {lists:flatten(String), ?STATUS_ERROR};
+	    {lists:flatten(String), ?STATUS_USAGE};
 	{String, Code}
           when is_list(String) and is_integer(Code) ->
 	    {lists:flatten(String), Code};
@@ -271,7 +301,7 @@ try_run_ctp(Args, Auth, AccessCommands, Version) ->
 	    try_call_command(Args, Auth, AccessCommands, Version);
 	false ->
 	    print_usage(Version),
-	    {"", ?STATUS_USAGE};
+	    {"", ?STATUS_BADRPC};
 	Status ->
 	    {"", Status}
     catch
@@ -288,7 +318,7 @@ try_run_ctp(Args, Auth, AccessCommands, Version) ->
 try_call_command(Args, Auth, AccessCommands, Version) ->
     try call_command(Args, Auth, AccessCommands, Version) of
 	{Reason, wrong_command_arguments} ->
-	    {Reason, ?STATUS_ERROR};
+	    {Reason, ?STATUS_USAGE};
 	Res ->
 	    Res
     catch
@@ -550,7 +580,8 @@ print_usage(HelpMode, MaxC, ShCode, Version) ->
     AllCommands = get_list_commands(Version),
 
     print(
-       ["Usage: ", "ejabberdctl", " [--no-timeout] [--node ", ?A("nodename"), "] [--version ", ?A("api_version"), "] ",
+       ["Usage: ", "ejabberdctl", " [--no-timeout] [--node ", ?A("name"), "] [--version ", ?A("apiv"), "] ",
+        "[--auth ", ?A("user host pass"), "] ",
 	?C("command"), " [", ?A("arguments"), "]\n"
 	"\n"
 	"Available commands in this ejabberd node:\n"], []),
