@@ -66,7 +66,6 @@
 		request_headers = [],
 		end_of_request = false,
 		options = [],
-		default_host,
 		custom_headers,
 		trail = <<>>,
 		allow_unencrypted_sasl2,
@@ -170,9 +169,8 @@ send_file(State, Fd, Size, FileName) ->
     try
 	case State#state.sockmod of
 	    gen_tcp ->
-		case file:sendfile(Fd, State#state.socket, 0, Size, []) of
-		    {ok, _} -> ok
-		end;
+		{ok, _} = file:sendfile(Fd, State#state.socket, 0, Size, []),
+		ok;
 	    _ ->
 		case file:read(Fd, ?SEND_BUF) of
 		    {ok, Data} ->
@@ -275,7 +273,7 @@ process_header(State, Data) ->
 		      request_headers = add_header(Name, Langs, State)};
       {ok, {http_header, _, 'Host' = Name, _, Value}} ->
 	  {Host, Port, TP} = get_transfer_protocol(State#state.addr_re, SockMod, Value),
-	  State#state{request_host = Host,
+	  State#state{request_host = ejabberd_config:resolve_host_alias(Host),
 		      request_port = Port,
 		      request_tp = TP,
 		      request_headers = add_header(Name, Value, State)};
@@ -301,7 +299,6 @@ process_header(State, Data) ->
 		    #state{sockmod = SockMod, socket = Socket,
 			   trail = State3#state.trail,
 			   options = State#state.options,
-			   default_host = State#state.default_host,
 			   custom_headers = State#state.custom_headers,
 			   request_handlers = State#state.request_handlers,
 			   addr_re = State#state.addr_re};
@@ -309,7 +306,6 @@ process_header(State, Data) ->
 		    #state{end_of_request = true,
 			   trail = State3#state.trail,
 			   options = State#state.options,
-			   default_host = State#state.default_host,
 			   custom_headers = State#state.custom_headers,
 			   request_handlers = State#state.request_handlers,
 			   addr_re = State#state.addr_re}
@@ -317,7 +313,6 @@ process_header(State, Data) ->
       _ ->
 	  #state{end_of_request = true,
 		 options = State#state.options,
-		 default_host = State#state.default_host,
 		 custom_headers = State#state.custom_headers,
 		 request_handlers = State#state.request_handlers,
 		 addr_re = State#state.addr_re}
@@ -927,8 +922,6 @@ listen_opt_type(request_handlers) ->
 	econf:binary(),
 	fun(Path) -> str:tokens(Path, <<"/">>) end),
       econf:beam([[{socket_handoff, 3}, {process, 2}]]));
-listen_opt_type(default_host) ->
-    econf:domain();
 listen_opt_type(custom_headers) ->
     econf:map(
       econf:binary(),
@@ -944,5 +937,4 @@ listen_options() ->
      {allow_unencrypted_sasl2, false},
      {request_handlers, []},
      {tag, <<>>},
-     {default_host, undefined},
      {custom_headers, []}].
