@@ -36,13 +36,14 @@
 	 l2i/1, i2l/1, i2l/2, expr_to_term/1, term_to_expr/1,
 	 now_to_usec/1, usec_to_now/1, encode_pid/1, decode_pid/2,
 	 compile_exprs/2, join_atoms/2, try_read_file/1, get_descr/2,
+	 get_home/0, warn_unset_home/0,
 	 css_dir/0, img_dir/0, js_dir/0, msgs_dir/0, sql_dir/0, lua_dir/0,
 	 read_css/1, read_img/1, read_js/1, read_lua/1,
 	 intersection/2, format_val/1, cancel_timer/1, unique_timestamp/0,
 	 is_mucsub_message/1, best_match/2, pmap/2, peach/2, format_exception/4,
 	 get_my_ipv4_address/0, get_my_ipv6_address/0, parse_ip_mask/1,
 	 crypto_hmac/3, crypto_hmac/4, uri_parse/1, uri_parse/2, uri_quote/1,
-         json_encode/1, json_decode/1, json_encode_with_kv_lists/1,
+         json_encode/1, json_decode/1,
 	 set_proc_label/1,
 	 match_ip_mask/3, format_hosts_list/1, format_cycle/1, delete_dir/1,
 	 semver_to_xxyy/1, logical_processors/0, get_mucsub_event_type/1]).
@@ -132,20 +133,18 @@ crypto_hmac(Type, Key, Data, MacL) -> crypto:macN(hmac, Type, Key, Data, MacL).
 -endif.
 
 -ifdef(OTP_BELOW_27).
-json_encode_with_kv_lists(Term) ->
-    jiffy:encode(Term).
 json_encode(Term) ->
     jiffy:encode(Term).
 json_decode(Bin) ->
     jiffy:decode(Bin, [return_maps]).
 -else.
-json_encode_with_kv_lists(Term) ->
+json_encode({[{_Key, _Value} | _]} = Term) ->
     iolist_to_binary(json:encode(Term,
 		     fun({Val}, Encoder) when is_list(Val) ->
 			 json:encode_key_value_list(Val, Encoder);
 			(Val, Encoder) ->
-			    json:encode_value(Val, Encoder)
-		     end)).
+			 json:encode_value(Val, Encoder)
+		     end));
 json_encode(Term) ->
     iolist_to_binary(json:encode(Term)).
 json_decode(Bin) ->
@@ -472,6 +471,25 @@ get_descr(Lang, Text) ->
     Copyright = ejabberd_config:get_copyright(),
     <<Desc/binary, $\n, Copyright/binary>>.
 
+-spec get_home() -> string().
+get_home() ->
+    case init:get_argument(home) of
+        {ok, [[Home]]} ->
+            Home;
+        error ->
+            mnesia:system_info(directory)
+    end.
+
+warn_unset_home() ->
+    case init:get_argument(home) of
+        {ok, [[_Home]]} ->
+            ok;
+        error ->
+            ?INFO_MSG("The 'HOME' environment variable is not set, "
+                 "ejabberd will use as HOME the Mnesia directory: ~s.",
+                 [mnesia:system_info(directory)])
+    end.
+
 -spec intersection(list(), list()) -> list().
 intersection(L1, L2) ->
     lists:filter(
