@@ -5,7 +5,7 @@
 %%% Created : 10 Aug 2008 by Badlop <badlop@process-one.net>
 %%%
 %%%
-%%% ejabberd, Copyright (C) 2002-2024   ProcessOne
+%%% ejabberd, Copyright (C) 2002-2025   ProcessOne
 %%%
 %%% This program is free software; you can redistribute it and/or
 %%% modify it under the terms of the GNU General Public License as
@@ -105,8 +105,8 @@
 %%%
 
 start(_Host, _Opts) ->
-    ejabberd_commands:register_commands(?MODULE, get_commands_spec()),
-    {ok, [{hook, webadmin_menu_main, web_menu_main, 50, global},
+    {ok, [{commands, get_commands_spec()},
+          {hook, webadmin_menu_main, web_menu_main, 50, global},
 	  {hook, webadmin_page_main, web_page_main, 50, global},
 	  {hook, webadmin_menu_host, web_menu_host, 50},
 	  {hook, webadmin_page_host, web_page_host, 50},
@@ -117,13 +117,8 @@ start(_Host, _Opts) ->
 	  {hook, webadmin_menu_node, web_menu_node, 50, global},
 	  {hook, webadmin_page_node, web_page_node, 50, global}]}.
 
-stop(Host) ->
-    case gen_mod:is_loaded_elsewhere(Host, ?MODULE) of
-	false ->
-	    ejabberd_commands:unregister_commands(get_commands_spec());
-	true ->
-	    ok
-    end.
+stop(_Host) ->
+    ok.
 
 reload(_Host, _NewOpts, _OldOpts) ->
     ok.
@@ -240,7 +235,7 @@ get_commands_spec() ->
      #ejabberd_commands{name = check_password_hash, tags = [accounts],
 			desc = "Check if the password hash is correct",
 			longdesc = "Allows hash methods from the Erlang/OTP "
-                        "[crypto](https://www.erlang.org/doc/man/crypto) application.",
+                        "[crypto](https://www.erlang.org/doc/apps/crypto/crypto.html) application.",
 			module = ?MODULE, function = check_password_hash,
 			args = [{user, binary}, {host, binary}, {passwordhash, binary},
 				{hashmethod, binary}],
@@ -729,7 +724,6 @@ get_commands_spec() ->
                         policy = user,
 			module = ?MODULE, function = get_roster_count,
 			args = [],
-			args_example = [<<"sun">>, <<"localhost">>],
 			args_rename = [{server, host}],
 			result_example = 5,
 			result_desc = "Number",
@@ -1905,16 +1899,20 @@ srg_create2(Group, Host, Label, Description, DisplayList) ->
     Opts = [{label, Label},
 	    {displayed_groups, DisplayList},
 	    {description, Description}],
-    {atomic, _} = mod_shared_roster:create_group(Host, Group, Opts),
-    ok.
+    case mod_shared_roster:create_group(Host, Group, Opts) of
+	{atomic, _} -> ok;
+	{error, Err} -> Err
+    end.
 
 srg_add(Group, Host) ->
     Opts = [{label, <<"">>},
             {description, <<"">>},
             {displayed_groups, []}
            ],
-    {atomic, _} = mod_shared_roster:create_group(Host, Group, Opts),
-    ok.
+    case mod_shared_roster:create_group(Host, Group, Opts) of
+	{atomic, _} -> ok;
+	{error, Err} -> Err
+    end.
 
 srg_delete(Group, Host) ->
     {atomic, _} = mod_shared_roster:delete_group(Host, Group),
